from typing import Dict, Any
from dataclasses import dataclass
from dataclasses_json import dataclass_json, LetterCase
from mlplatform_lib.dataclass.model import ModelDto


@dataclass_json(letter_case=LetterCase.CAMEL)
@dataclass
class ModelPredefinedaiDto(ModelDto):
    algorithm: str
    metric: str
    metric_result: str



from setuptools import setup, find_packages


# version = {hyperdata_version}.{mlplatform_version}.{union_test_version}.{human_number}.{test_number}
# ex)        8.4.0             .0                   .0.2.1
# mansu: 0
# jooyoun: 1
# yunho: 2
setup(
    name="mlplatform_lib",
    version="8.4.0.0.0.0.4",
    description="mlplatform_lib",
    author="mlplatform_lib",
    author_email="mansu_kim@tmax.co.kr",
    url="",
    download_url="",
    install_requires=["pandas>=1.0.1", "requests>=2.25.1", "dataclasses_json>=0.5.4"],
    packages=find_packages(exclude=[]),
    keywords=["mlplatform_lib"],
    python_requires=">=3.7",
    package_data={},
    zip_safe=False,
    classifiers=["Programming Language :: Python :: 3.7"],
)
